ErrorHandlerVar class

Constructors

ErrorHandlerVar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appVersion String
getter/setter pair
chatIdTelegram String
getter/setter pair
device String
Device Data
getter/setter pair
errorMessageFromBackend String
getter/setter pair
isSendToTelegram bool
Send To Telegram
getter/setter pair
tokenTelegramPrivate String
Key
getter/setter pair